@@ -1,7 +1,13 @@
 <?php
-/* $Id: Table.class.php 9856 2007-01-21 13:13:42Z lem9 $ */
-// vim: expandtab sw=4 ts=4 sts=4:
+/* vim: set expandtab sw=4 ts=4 sts=4: */
+/**
+ *
+ * @version $Id: Table.class.php 11214 2008-04-24 17:05:50Z lem9 $
+ */
 
+/**
+ *
+ */
 class PMA_Table {
 
     /**
@@ -133,11 +139,11 @@ class PMA_Table {
 
     function isView($db = null, $table = null)
     {
-        if (null !== $db && null !== $table) {
+        if (strlen($db) && strlen($table)) {
             return PMA_Table::_isView($db, $table);
         }
 
-        if (strpos($this->get('TABLE TYPE'), 'VIEW')) {
+        if (isset($this) && strpos($this->get('TABLE TYPE'), 'VIEW')) {
             return true;
         }
 
@@ -246,7 +252,9 @@ class PMA_Table {
         // MySQL from 5.0.0 to 5.0.12 returns 'view',
         // from 5.0.13 returns 'VIEW'.
         $comment = strtoupper(PMA_DBI_fetch_value('SHOW TABLE STATUS FROM ' . PMA_backquote($db) . ' LIKE \'' . $table . '\'', 0, 'Comment'));
-        return ($comment == 'VIEW');
+        // use substr() because the comment might contain something like:
+        // (VIEW 'BASE2.VTEST' REFERENCES INVALID TABLE(S) OR COLUMN(S) OR FUNCTION)
+        return (substr($comment, 0, 4) == 'VIEW');
     }
 
     /**
@@ -320,10 +328,12 @@ class PMA_Table {
                 $query .= ' DEFAULT NULL';
             } else {
                 if (strlen($default)) {
-                    if ($is_timestamp) {
+                    if ($is_timestamp && $default == '0') {
                         // a TIMESTAMP does not accept DEFAULT '0'
                         // but DEFAULT 0  works
                         $query .= ' DEFAULT ' . PMA_sqlAddslashes($default);
+                    } elseif ($default && $type == 'BIT') {
+                        $query .= ' DEFAULT b\'' . preg_replace('/[^01]/', '0', $default) . '\'';
                     } else {
                         $query .= ' DEFAULT \'' . PMA_sqlAddslashes($default) . '\'';
                     }
@@ -333,16 +343,32 @@ class PMA_Table {
 
         if (!empty($extra)) {
             $query .= ' ' . $extra;
-            // An auto_increment field must be use as a primary key
-            if ($extra == 'AUTO_INCREMENT' && isset($field_primary)) {
+            // Force an auto_increment field to be part of the primary key
+            // even if user did not tick the PK box; 
+            if ($extra == 'AUTO_INCREMENT') {
                 $primary_cnt = count($field_primary);
-                for ($j = 0; $j < $primary_cnt && $field_primary[$j] != $index; $j++) {
-                    // void
-                } // end for
-                if (isset($field_primary[$j]) && $field_primary[$j] == $index) {
-                    $query .= ' PRIMARY KEY';
-                    unset($field_primary[$j]);
-                } // end if
+                if (1 == $primary_cnt) {
+                    for ($j = 0; $j < $primary_cnt && $field_primary[$j] != $index; $j++) {
+                        //void
+                    }
+                    if (isset($field_primary[$j]) && $field_primary[$j] == $index) {
+                        $query .= ' PRIMARY KEY';
+                        unset($field_primary[$j]);
+                    }
+                // but the PK could contain other columns so do not append
+                // a PRIMARY KEY clause, just add a member to $field_primary
+                } else {
+                    $found_in_pk = false;
+                    for ($j = 0; $j < $primary_cnt; $j++) {
+                        if ($field_primary[$j] == $index) {
+                            $found_in_pk = true;
+                            break;
+                        }
+                    } // end for
+                    if (! $found_in_pk) {
+                        $field_primary[] = $index;
+                    }
+                }
             } // end if (auto_increment)
         }
         if (PMA_MYSQL_INT_VERSION >= 40100 && !empty($comment)) {
@@ -396,7 +422,7 @@ class PMA_Table {
                 } else {
                     // Counting all rows of a VIEW could be too long, so use
                     // a LIMIT clause.
-                    // Use try_query because it can fail ( a VIEW is based on
+                    // Use try_query because it can fail (a VIEW is based on
                     // a table that no longer exists)
                     $result = PMA_DBI_try_query(
                         'SELECT 1 FROM ' . PMA_backquote($db) . '.'
@@ -466,7 +492,7 @@ class PMA_Table {
     {
         $last_id = -1;
 
-        if ($GLOBALS['cfgRelation'][$work]) {
+        if (isset($GLOBALS['cfgRelation']) && $GLOBALS['cfgRelation'][$work]) {
             $select_parts = array();
             $row_fields = array();
             foreach ($get_fields as $get_field) {
@@ -543,10 +569,6 @@ class PMA_Table {
     {
         global $err_url;
 
-        if (! isset($GLOBALS['sql_query'])) {
-            $GLOBALS['sql_query'] = '';
-        }
-
         // set export settings we need
         $GLOBALS['sql_backquotes'] = 1;
         $GLOBALS['asfile']         = 1;
@@ -575,7 +597,7 @@ class PMA_Table {
             require_once './libraries/export/sql.php';
 
             $no_constraints_comments = true;
-        $GLOBALS['sql_constraints_query'] = '';
+            $GLOBALS['sql_constraints_query'] = '';
 
             $sql_structure = PMA_getTableDef($source_db, $source_table, "\n", $err_url);
             unset($no_constraints_comments);
@@ -593,29 +615,36 @@ class PMA_Table {
                 }
             }
             unset($analyzed_sql);
+            $server_sql_mode = PMA_DBI_fetch_value("SHOW VARIABLES LIKE 'sql_mode'", 0, 1);
+            if ('ANSI_QUOTES' == $server_sql_mode) {
+                $table_delimiter = 'quote_double';
+            } else {
+                $table_delimiter = 'quote_backtick';
+            }
+            unset($server_sql_mode);
 
             /* nijel: Find table name in query and replace it */
-            while ($parsed_sql[$i]['type'] != 'quote_backtick') {
+            while ($parsed_sql[$i]['type'] != $table_delimiter) {
                 $i++;
             }
 
             /* no need to PMA_backquote() */
-	    if (isset($target_for_view)) {
-		// this a view definition; we just found the first db name
-		// that follows DEFINER VIEW
-		// so change it for the new db name
-                $parsed_sql[$i]['data'] = $target_for_view;
-		// then we have to find all references to the source db 
-		// and change them to the target db, ensuring we stay into
-		// the $parsed_sql limits
-		$last = $parsed_sql['len'] - 1;
-		$backquoted_source_db = PMA_backquote($source_db);
-		for (++$i; $i <= $last; $i++) { 
-            	    if ($parsed_sql[$i]['type'] == 'quote_backtick' && $parsed_sql[$i]['data'] == $backquoted_source_db) {
+            if (isset($target_for_view)) {
+                // this a view definition; we just found the first db name
+                // that follows DEFINER VIEW
+                // so change it for the new db name
                         $parsed_sql[$i]['data'] = $target_for_view;
-		    }
-		}
-		unset($last,$backquoted_source_db);
+                // then we have to find all references to the source db
+                // and change them to the target db, ensuring we stay into
+                // the $parsed_sql limits
+                $last = $parsed_sql['len'] - 1;
+                $backquoted_source_db = PMA_backquote($source_db);
+                for (++$i; $i <= $last; $i++) {
+                            if ($parsed_sql[$i]['type'] == $table_delimiter && $parsed_sql[$i]['data'] == $backquoted_source_db) {
+                                $parsed_sql[$i]['data'] = $target_for_view;
+                    }
+                }
+                unset($last,$backquoted_source_db);
             } else {
                 $parsed_sql[$i]['data'] = $target;
             }
@@ -651,10 +680,10 @@ class PMA_Table {
                 $parsed_sql =  PMA_SQP_parse($GLOBALS['sql_constraints_query']);
                 $i = 0;
 
-                // find the first quote_backtick, it must be the source table name
-                while ($parsed_sql[$i]['type'] != 'quote_backtick') {
+                // find the first $table_delimiter, it must be the source table name
+                while ($parsed_sql[$i]['type'] != $table_delimiter) {
                     $i++;
-            // maybe someday we should guard against going over limit
+                    // maybe someday we should guard against going over limit
                     //if ($i == $parsed_sql['len']) {
                     //    break;
                     //}
@@ -663,7 +692,7 @@ class PMA_Table {
                 // replace it by the target table name, no need to PMA_backquote()
                 $parsed_sql[$i]['data'] = $target;
 
-                // now we must remove all quote_backtick that follow a CONSTRAINT
+                // now we must remove all $table_delimiter that follow a CONSTRAINT
                 // keyword, because a constraint name must be unique in a db
 
                 $cnt = $parsed_sql['len'] - 1;
@@ -671,7 +700,7 @@ class PMA_Table {
                 for ($j = $i; $j < $cnt; $j++) {
                     if ($parsed_sql[$j]['type'] == 'alpha_reservedWord'
                       && strtoupper($parsed_sql[$j]['data']) == 'CONSTRAINT') {
-                        if ($parsed_sql[$j+1]['type'] == 'quote_backtick') {
+                        if ($parsed_sql[$j+1]['type'] == $table_delimiter) {
                             $parsed_sql[$j+1]['data'] = '';
                         }
                     }
@@ -680,15 +709,14 @@ class PMA_Table {
                 // Generate query back
                 $GLOBALS['sql_constraints_query'] = PMA_SQP_formatHtml($parsed_sql,
                     'query_only');
-            if ($mode == 'one_table') {
+                if ($mode == 'one_table') {
                     PMA_DBI_query($GLOBALS['sql_constraints_query']);
-        }
+                }
                 $GLOBALS['sql_query'] .= "\n" . $GLOBALS['sql_constraints_query'];
-            if ($mode == 'one_table') {
+                if ($mode == 'one_table') {
                     unset($GLOBALS['sql_constraints_query']);
-        }
+                }
             }
-
         } else {
             $GLOBALS['sql_query'] = '';
         }
@@ -795,8 +823,19 @@ class PMA_Table {
                 */
             }
 
+            if ($GLOBALS['cfgRelation']['designerwork']) {
+                $table_query = 'UPDATE ' . PMA_backquote($GLOBALS['cfgRelation']['db']) . '.' . PMA_backquote($GLOBALS['cfgRelation']['designer_coords'])
+                                . ' SET     table_name = \'' . PMA_sqlAddslashes($target_table) . '\','
+                                . '         db_name = \'' . PMA_sqlAddslashes($target_db) . '\''
+                                . ' WHERE db_name  = \'' . PMA_sqlAddslashes($source_db) . '\''
+                                . ' AND table_name = \'' . PMA_sqlAddslashes($source_table) . '\'';
+                PMA_query_as_cu($table_query);
+                unset($table_query);
+            }
             $GLOBALS['sql_query']      .= "\n\n" . $sql_drop_query . ';';
+        // end if ($move)
         } else {
+            // we are copying
             // garvin: Create new entries as duplicates from old PMA DBs
             if ($what != 'dataonly' && !isset($maintain_relations)) {
                 if ($GLOBALS['cfgRelation']['commwork']) {
@@ -835,16 +874,27 @@ class PMA_Table {
                 $where_fields = array('db_name' => $source_db, 'table_name' => $source_table);
                 $new_fields = array('db_name' => $target_db, 'table_name' => $target_table);
                 PMA_Table::duplicateInfo('displaywork', 'table_info', $get_fields, $where_fields, $new_fields);
+                
 
-                $get_fields = array('master_field', 'foreign_db', 'foreign_table', 'foreign_field');
+                /**
+                 * @todo revise this code when we support cross-db relations
+                 */
+                $get_fields = array('master_field', 'foreign_table', 'foreign_field');
                 $where_fields = array('master_db' => $source_db, 'master_table' => $source_table);
-                $new_fields = array('master_db' => $target_db, 'master_table' => $target_table);
+                $new_fields = array('master_db' => $target_db, 'foreign_db' => $target_db, 'master_table' => $target_table);
                 PMA_Table::duplicateInfo('relwork', 'relation', $get_fields, $where_fields, $new_fields);
+                
 
-                $get_fields = array('foreign_field', 'master_db', 'master_table', 'master_field');
+                $get_fields = array('foreign_field', 'master_table', 'master_field');
                 $where_fields = array('foreign_db' => $source_db, 'foreign_table' => $source_table);
-                $new_fields = array('foreign_db' => $target_db, 'foreign_table' => $target_table);
+                $new_fields = array('master_db' => $target_db, 'foreign_db' => $target_db, 'foreign_table' => $target_table);
                 PMA_Table::duplicateInfo('relwork', 'relation', $get_fields, $where_fields, $new_fields);
+                
+
+                $get_fields = array('x', 'y', 'v', 'h');
+                $where_fields = array('db_name' => $source_db, 'table_name' => $source_table);
+                $new_fields = array('db_name' => $target_db, 'table_name' => $target_table);
+                PMA_Table::duplicateInfo('designerwork', 'designer_coords', $get_fields, $where_fields, $new_fields);
 
                 /**
                  * @todo garvin: Can't get duplicating PDFs the right way. The
@@ -1005,6 +1055,18 @@ class PMA_Table {
             unset($table_query);
         }
 
+        if ($GLOBALS['cfgRelation']['designerwork']) {
+            $table_query = '
+                UPDATE ' . PMA_backquote($GLOBALS['cfgRelation']['db']) . '.'
+                    . PMA_backquote($GLOBALS['cfgRelation']['designer_coords']) . '
+                   SET `db_name`    = \'' . PMA_sqlAddslashes($new_db) . '\',
+                       `table_name` = \'' . PMA_sqlAddslashes($new_name) . '\'
+                 WHERE `db_name`    = \'' . PMA_sqlAddslashes($old_db) . '\'
+                   AND `table_name` = \'' . PMA_sqlAddslashes($old_name) . '\'';
+            PMA_query_as_cu($table_query);
+            unset($table_query);
+        }
+
         $this->messages[] = sprintf($GLOBALS['strRenameTableOK'],
             htmlspecialchars($old_name), htmlspecialchars($new_name));
         return true;
